---
id: version-0.0.1-scripts
title: Scripts
sidebar_label: Scripts
original_id: scripts
---

There are two categories of scripts one can write when developing a SOIL application: scripts that run when something happens for example when new data arrives and scripts that run on a schedule.

The entry points for these scripts are defined in the `soil.yml` file on the top of the project.

TODO explain how to create entry points, the syntax of the file etc.
